Module blaxel.core.client.models.mcp_definition
===============================================

Classes
-------

`MCPDefinition(created_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, updated_at: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, categories: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, coming_soon: blaxel.core.client.types.Unset | bool = <blaxel.core.client.types.Unset object>, description: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, display_name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, enterprise: blaxel.core.client.types.Unset | bool = <blaxel.core.client.types.Unset object>, entrypoint: blaxel.core.client.types.Unset | ForwardRef('MCPDefinitionEntrypoint') = <blaxel.core.client.types.Unset object>, form: blaxel.core.client.types.Unset | ForwardRef('MCPDefinitionForm') = <blaxel.core.client.types.Unset object>, hidden_secrets: blaxel.core.client.types.Unset | list[str] = <blaxel.core.client.types.Unset object>, icon: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, image: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, integration: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, long_description: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, transport: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, url: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Definition of an MCP from the MCP Hub
    
    Attributes:
        created_at (Union[Unset, str]): The date and time when the resource was created
        updated_at (Union[Unset, str]): The date and time when the resource was updated
        categories (Union[Unset, list[Any]]): Categories of the artifact
        coming_soon (Union[Unset, bool]): If the artifact is coming soon
        description (Union[Unset, str]): Description of the artifact
        display_name (Union[Unset, str]): Display name of the artifact
        enterprise (Union[Unset, bool]): If the artifact is enterprise
        entrypoint (Union[Unset, MCPDefinitionEntrypoint]): Entrypoint of the artifact
        form (Union[Unset, MCPDefinitionForm]): Form of the artifact
        hidden_secrets (Union[Unset, list[str]]): Hidden secrets of the artifact
        icon (Union[Unset, str]): Icon of the artifact
        image (Union[Unset, str]): Image of the artifact
        integration (Union[Unset, str]): Integration of the artifact
        long_description (Union[Unset, str]): Long description of the artifact
        name (Union[Unset, str]): Name of the artifact
        transport (Union[Unset, str]): Transport compatibility for the MCP, can be "websocket" or "http-stream"
        url (Union[Unset, str]): URL of the artifact
    
    Method generated by attrs for class MCPDefinition.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `categories`
    :

    `coming_soon`
    :

    `created_at`
    :

    `description`
    :

    `display_name`
    :

    `enterprise`
    :

    `entrypoint`
    :

    `form`
    :

    `hidden_secrets`
    :

    `icon`
    :

    `image`
    :

    `integration`
    :

    `long_description`
    :

    `name`
    :

    `transport`
    :

    `updated_at`
    :

    `url`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :